package javax.swing.plaf.synth;

import java.awt.Graphics;
import javax.swing.text.Style;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyledDocument;
import javax.swing.text.JTextComponent;
import java.awt.Color;
import java.awt.Font;
import java.beans.PropertyChangeEvent;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;

public class SynthTextPaneUI extends SynthEditorPaneUI
{
    public SynthTextPaneUI() {
    }
    
    public static ComponentUI createUI(JComponent component) {
        return new SynthTextPaneUI();
    }
    
    @Override
    protected String getPropertyPrefix() {
        return "TextPane";
    }
    
    @Override
    public void installUI(JComponent c) {
        super.installUI(c);
        this.updateForeground(c.getForeground());
        this.updateFont(c.getFont());
    }
    
    @Override
    protected void propertyChange(PropertyChangeEvent propertyChangeEvent) {
        super.propertyChange(propertyChangeEvent);
        String propertyName = propertyChangeEvent.getPropertyName();
        if (propertyName.equals("foreground")) {
            this.updateForeground((Color)propertyChangeEvent.getNewValue());
        }
        else if (propertyName.equals("font")) {
            this.updateFont((Font)propertyChangeEvent.getNewValue());
        }
        else if (propertyName.equals("document")) {
            JTextComponent component = this.getComponent();
            this.updateForeground(component.getForeground());
            this.updateFont(component.getFont());
        }
    }
    
    private void updateForeground(Color fg) {
        Style style = ((StyledDocument)this.getComponent().getDocument()).getStyle("default");
        if (style == null) {
            return;
        }
        if (fg == null) {
            style.removeAttribute(StyleConstants.Foreground);
        }
        else {
            StyleConstants.setForeground(style, fg);
        }
        return;
    }
    
    private void updateFont(Font font) {
        Style style = ((StyledDocument)this.getComponent().getDocument()).getStyle("default");
        if (style == null) {
            return;
        }
        if (font == null) {
            style.removeAttribute(StyleConstants.FontFamily);
            style.removeAttribute(StyleConstants.FontSize);
            style.removeAttribute(StyleConstants.Bold);
            style.removeAttribute(StyleConstants.Italic);
        }
        else {
            StyleConstants.setFontFamily(style, font.getName());
            StyleConstants.setFontSize(style, font.getSize());
            StyleConstants.setBold(style, font.isBold());
            StyleConstants.setItalic(style, font.isItalic());
        }
        return;
    }
    
    @Override
    void paintBackground(SynthContext synthContext, Graphics graphics, JComponent component) {
        synthContext.getPainter().paintTextPaneBackground(synthContext, graphics, 0, 0, component.getWidth(), component.getHeight());
    }
    
    @Override
    public void paintBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        synthContext.getPainter().paintTextPaneBorder(synthContext, graphics, n, n2, n3, n4);
    }
}
